
# Emergence (or emergent)

> [!INFO]Definition
> Since simple rules produce complex behaviour in hard-to-predict ways, the macroscopic behavior of such systems is sometimes called emergent ^[@mitchell2009].

To be more specific, there are **four types of emergencies**:

=== "Simple Emergence"
	![CleanShot2023-01-17at11.29.48@2x](https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/CleanShot%202023-01-17%20at%2011.29.48@2x.png){:style="height:130px; width:200px" align='right'}
	> Without any bottom-top feedback, each component uniquely determines the state at the next moment. This form of emergence is characterised by fragility, where the destruction of a single component can cause the system to stop working.

=== "Weak Emergence"

	> If the macro pattern can only be simulated from the micro components' dynamics, then he is weakly emergent. It can be made stable (e.g., ants foraging) or non-stable (e.g., financial markets, subordination).

=== "Multiple Emergence"

	> Both negative feedback that makes the system stable and positive feedback that makes the system non-stable. Many complex patterns are emergent as a result.

=== "Strong Emergence"

	> Emergent systems that emerge at a higher level of organisation or complexity, such as culture, language and writing systems, life, and geographic zoning...